@@ -302,11 +302,9 @@ def node_power_action(task, new_state, timeout=None):
 
     # Set the target_power_state and clear any last_error, if we're
     # starting a new operation. This will expose to other processes
-    # and clients that work is in progress. Keep the last_error intact
-    # if the power action happens as a result of a failure.
-    node.target_power_state = target_state
-    if node.provision_state not in states.FAILURE_STATES:
-        node.last_error = None
+    # and clients that work is in progress.
+    node['target_power_state'] = target_state
+    node['last_error'] = None
     node.timestamp_driver_internal_info('last_power_state_change')
     # NOTE(dtantsur): wipe token on shutting down, otherwise a reboot in
     # fast-track (or an accidentally booted agent) will cause subsequent
@@ -481,9 +479,9 @@ def cleaning_error_handler(task, logmsg, errmsg=None, traceback=False,
         node.del_driver_internal_info('cleaning_reboot')
         node.del_driver_internal_info('cleaning_polling')
         node.del_driver_internal_info('skip_current_clean_step')
-        # We don't need to keep the old agent URL, or token
+        # We don't need to keep the old agent URL
         # as it should change upon the next cleaning attempt.
-        wipe_token_and_url(task)
+        node.del_driver_internal_info('agent_url')
     # For manual cleaning, the target provision state is MANAGEABLE, whereas
     # for automated cleaning, it is AVAILABLE.
     manual_clean = node.target_provision_state == states.MANAGEABLE
@@ -940,7 +938,7 @@ def notify_conductor_resume_deploy(task):
     notify_conductor_resume_operation(task, 'deploy')
 
 
-def skip_automated_cleaning(node, log=True):
+def skip_automated_cleaning(node):
     """Checks if node cleaning needs to be skipped for an specific node.
 
     :param node: the node to consider
@@ -950,9 +948,9 @@ def skip_automated_cleaning(node, log=True):
     elif node.automated_clean is None:
         return not CONF.conductor.automated_clean
     else:
-        if log:
-            LOG.info("Automated cleaning is disabled via the API for "
-                     "node %(node)s", {'node': node.uuid})
+        LOG.info("Automated cleaning is disabled via the API for "
+                 "node %(node)s",
+                 {'node': node.uuid})
         return True
 
 
