@@ -22,6 +22,7 @@ from ironic.common import exception
 from ironic.conductor import task_manager
 from ironic import drivers as ironic_drivers
 from ironic.drivers.modules import deploy_utils
+from ironic.drivers.modules.irmc import common as irmc_common
 from ironic.drivers.modules.irmc import raid
 from ironic.tests.unit.drivers.modules.irmc import test_common
 
@@ -702,7 +703,7 @@ class IRMCRaidConfigurationInternalMethodsTestCase(test_common.BaseIRMCTest):
                                   shared=True) as task:
             raid._commit_raid_config(task)
             get_raid_adapter_mock.assert_called_once_with(
-                task.node.driver_info)
+                irmc_common.parse_driver_info(task.node))
             update_raid_info_mock.assert_called_once_with(
                 task.node, task.node.raid_config)
             set_async_step_flags_mock.assert_called_once_with(
